==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareRAIDVolumeBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HardwareRAIDVolumeBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeBuilder>{
  public HardwareRAIDVolumeBuilder() {
    this(false);
  }
  public HardwareRAIDVolumeBuilder(java.lang.Boolean validationEnabled) {
    this(new HardwareRAIDVolume(), validationEnabled);
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HardwareRAIDVolume(), validationEnabled);
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume instance) {
    this(fluent, instance, false);
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLevel(instance.getLevel()); 
    fluent.withName(instance.getName()); 
    fluent.withNumberOfPhysicalDisks(instance.getNumberOfPhysicalDisks()); 
    fluent.withRotational(instance.getRotational()); 
    fluent.withSizeGibibytes(instance.getSizeGibibytes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume instance) {
    this(instance,false);
  }
  public HardwareRAIDVolumeBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLevel(instance.getLevel()); 
    this.withName(instance.getName()); 
    this.withNumberOfPhysicalDisks(instance.getNumberOfPhysicalDisks()); 
    this.withRotational(instance.getRotational()); 
    this.withSizeGibibytes(instance.getSizeGibibytes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolumeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareRAIDVolume build() {
    HardwareRAIDVolume buildable = new HardwareRAIDVolume(fluent.getLevel(),fluent.getName(),fluent.getNumberOfPhysicalDisks(),fluent.getRotational(),fluent.getSizeGibibytes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HardwareRAIDVolumeBuilder that = (HardwareRAIDVolumeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareRAIDVolumeBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HardwareRAIDVolumeBuilder extends HardwareRAIDVolumeFluentImpl<HardwareRAIDVolumeBuilder> implements VisitableBuilder<HardwareRAIDVolume,HardwareRAIDVolumeBuilder>{
  public HardwareRAIDVolumeBuilder() {
    this(false);
  }
  public HardwareRAIDVolumeBuilder(Boolean validationEnabled) {
    this(new HardwareRAIDVolume(), validationEnabled);
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolumeFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolumeFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HardwareRAIDVolume(), validationEnabled);
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolumeFluent<?> fluent,HardwareRAIDVolume instance) {
    this(fluent, instance, false);
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolumeFluent<?> fluent,HardwareRAIDVolume instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLevel(instance.getLevel()); 
    fluent.withName(instance.getName()); 
    fluent.withNumberOfPhysicalDisks(instance.getNumberOfPhysicalDisks()); 
    fluent.withRotational(instance.getRotational()); 
    fluent.withSizeGibibytes(instance.getSizeGibibytes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolume instance) {
    this(instance,false);
  }
  public HardwareRAIDVolumeBuilder(HardwareRAIDVolume instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLevel(instance.getLevel()); 
    this.withName(instance.getName()); 
    this.withNumberOfPhysicalDisks(instance.getNumberOfPhysicalDisks()); 
    this.withRotational(instance.getRotational()); 
    this.withSizeGibibytes(instance.getSizeGibibytes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  HardwareRAIDVolumeFluent<?> fluent;
  Boolean validationEnabled;
  public HardwareRAIDVolume build() {
    HardwareRAIDVolume buildable = new HardwareRAIDVolume(fluent.getLevel(),fluent.getName(),fluent.getNumberOfPhysicalDisks(),fluent.getRotational(),fluent.getSizeGibibytes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
